make_lid = false;
make_base = false;

use <../libs/rounded_shapes.scad>
rpi_width = 65;
rpi_depth = 30;

border_dim = 5.5;

base_thickness = 2.1;

margin_dim = 3.5;

locking_ridge_height = 2.0;
locking_ridge_width = 1.5;

overall_width = rpi_width + (2*border_dim) + (2*margin_dim) + (2*locking_ridge_width);
overall_depth = rpi_depth + (2*border_dim) + (2*margin_dim) + (2*locking_ridge_width);

standoff_height = 2.0 + locking_ridge_height;

$fn = 44;

mounting_hole_dia = 2.5;
rpi_zero_board_thickness = 3.0;

mount_screw_dia = 11/64.0 * 25.4;
mount_screw_hole_radius = mount_screw_dia * 1.05 / 2.0;

lid_thickness = 2.5;
lid_height = 15 + lid_thickness + 3.5;

bnc_mount_dia = 25.4 * 24.0/64.0;

header_pins_offset_from_top = 8.5;

module peaked_standoff(height, hole_dia, board_thickness){
  union(){
  cylinder(r1 = hole_dia * (1.0 + 0.75) / 2.0, r2 = hole_dia * (1.0 + 0.33) / 2.0, h = height);
    translate([0,0,height]){
      cylinder( r1 = hole_dia * (1.0 - 0.03) / 2.0,  r2 = hole_dia * (1.0-0.08)/2.0, h = board_thickness);
    }
  }
  
}

lid_mount_screw_radius = 2.73 / 2.0;
mount_box_dim = border_dim;

module mounting_box(){
  difference(){
    cube([mount_box_dim,mount_box_dim,10]);
    translate([mount_box_dim/2,mount_box_dim/2, -1]){
      cylinder( r = lid_mount_screw_radius, h = 10 + 2);
    }
  }
}

module lid_mounting(){
  translate([0, overall_depth/2.0 - mount_box_dim/2.0,0]){
     mounting_box();
  }
  
  translate([overall_width - mount_box_dim, overall_depth/2.0 - mount_box_dim/2.0,0]){
     mounting_box(); 
  }
}


if (make_base) {
// The base
difference(){ 
  union(){
    lid_mounting();
    rounded_rectangle(overall_width, overall_depth, base_thickness, 4);
    translate([border_dim,border_dim,base_thickness]){
      difference(){
      color("red") cube([ rpi_width + (2*margin_dim) + (2*locking_ridge_width), rpi_depth + (2*margin_dim) + (2*locking_ridge_width), locking_ridge_height]);
        translate([locking_ridge_width, locking_ridge_width, -1]){
          cube([rpi_width + (2*margin_dim) , rpi_depth + (2*margin_dim) , locking_ridge_height + 2]);
        }
      }
    }
    
    translate([border_dim + margin_dim + locking_ridge_width, border_dim + margin_dim + locking_ridge_width,base_thickness]){
      translate([3.5, 3.5,0]){
        peaked_standoff(standoff_height, mounting_hole_dia, rpi_zero_board_thickness);  
      }
      
      translate([3.5, rpi_depth - 3.5, 0]){
        peaked_standoff(standoff_height, mounting_hole_dia, rpi_zero_board_thickness);  
      }
      
      translate([rpi_width - 3.5, rpi_depth - 3.5, 0]){
        peaked_standoff(standoff_height, mounting_hole_dia, rpi_zero_board_thickness);  
      }
      
      translate([rpi_width - 3.5, 3.5, 0]){
        peaked_standoff(standoff_height, mounting_hole_dia, rpi_zero_board_thickness);  
      }
    }
    
    
  }
  
  translate([overall_width/2.0, overall_depth/2.0, -1]){
    translate([-1.0 * overall_width /4.0, 0, 0]){
      cylinder(r = mount_screw_hole_radius, h = base_thickness *2);
    }
    
    translate([overall_width /4.0, 0, 0]){
      cylinder(r = mount_screw_hole_radius, h = base_thickness *2);
    }
  }
}
}

// The lid


if (make_lid) {
translate([0,0,20]){
  union(){
    difference(){
     rounded_rectangle(overall_width, overall_depth, lid_height, 4);
      translate([overall_width/2 - 8, overall_depth/2 - 4, 0]){
        cylinder(r = bnc_mount_dia / 2.0 * 1.043, h = 100);
      }
     translate([-1,-1,-1]){
       cube([overall_width + 2, 3* overall_depth  / 16.0, lid_height + 2]);
     }
     translate([border_dim, border_dim,-1]){
       cube([rpi_width + 2 * locking_ridge_width + 2 * margin_dim, rpi_depth + 2 * locking_ridge_width + 2*margin_dim,lid_height + 1 - lid_thickness]);
       
     }
     
    translate([0, overall_depth/2.0 - mount_box_dim/2.0,0]){
      translate([-1,0,-1]){
       cube([mount_box_dim + 2,mount_box_dim + 0.2,10 + 0.2]);       
      }
      
      translate([mount_box_dim/2,mount_box_dim/2, -1]){
        cylinder( r = lid_mount_screw_radius * 1.2, h = lid_height  * 2);
      }    
    }
    
    
    translate([overall_width - mount_box_dim , overall_depth/2.0 - mount_box_dim/2.0,]){
      translate([-1,0,-1]){
        cube([mount_box_dim + 2,mount_box_dim + 0.2,10 + 0.2]);
      }
      translate([mount_box_dim/2,mount_box_dim/2, -1]){
        cylinder( r = lid_mount_screw_radius * 1.2, h = lid_height  * 2);
      } 
    }
    
    translate([border_dim + margin_dim + locking_ridge_width + 2,overall_depth - margin_dim - border_dim - locking_ridge_width -  header_pins_offset_from_top ,-1]){
      rounded_rectangle(rpi_width / 3.0,border_dim + 20 +  header_pins_offset_from_top + margin_dim,100,3);
    }
    
  }

}
}

}
